# Get top 10 shell commands
alias top10='print -l ${(o)history%% *} | uniq -c | sort -nr | head -n 10'

# history mechanism
alias h='history'

# Aliases for APT
if [ -e "/etc/debian_version" ]; then
    alias acs="sudo apt-cache search"
    alias acp="sudo apt-cache policy"
    alias afs="sudo apt-file search"
    alias afu="sudo apt-file update"
    alias aac="sudo apt autoclean"
    alias agc="sudo apt clean"
    alias agi="sudo apt install"
    alias agli="sudo apt list --installed"
    alias agp="sudo apt purge"
    alias agr="sudo apt remove"
    alias agu="sudo apt update"
    alias agud="sudo apt update && sudo apt dist-upgrade"
    alias agar="sudo apt autoremove"
fi

if [ -e "/etc/redhat-release" ]; then
    alias dnfc='sudo dnf clean all'
    alias dnfgi='sudo dnf groupinstall'
    alias dnfgl='dnf grouplist'
    alias dnfgr='sudo dnf groupremove'
    alias dnfi='sudo dnf install'
    alias dnfl='dnf list'
    alias dnfli='dnf list installed'
    alias dnfmc='dnf makecache'
    alias dnfp='dnf info'
    alias dnfr='sudo dnf remove'
    alias dnfs='dnf search'
    alias dnfu='sudo dnf update'
fi

# Convert UPPER to lower (or back)
alias UP2low='for i in *(.); mv $i ${i:l}'
alias low2UP='for i in *(.); mv $i ${i:u}'

# The ls family
if test -x "$(command -v exa)"; then
    alias ls='exa'
else
    alias ls='ls --color=auto'
fi

alias l='ls -lFhg'
alias la='ls -a'
alias ll='ls -l'
alias lal='ls -al'
alias ldot='ls -gld .*'
alias lse='/bin/ls -lZ'

# greps
alias grep='grep --color'
alias sgrep='grep -R -n -H -C 5 --exclude-dir={.git,.svn,CVS}'

# Copy SSH public key to clipboard (requires xclip or xsel)
if test -x "$(command -v xclip)"; then
    alias pubkey='more ~/.ssh/id_ed25519.pub | xclip -selection clipboard | echo "SSH public key copied"'
fi

# Prompt user before overwriting files
alias cp='cp -i'
alias mv='mv -i'
alias rm='trash'
alias del='rm -i'

# Display zsh functions with bat
alias zfun='functions | bat -l zsh'

# Assorted global aliases
alias -g H='| head'
alias -g T='| tail'
alias -g G='| grep'
alias -g L='| less -X'
alias -g B='| bat'
alias -g LL='2>&1 | less'
alias -g NE='2> /dev/null'
alias -g NUL='> /dev/null 2>&1'
alias -g P='2>&1| pygmentize -l pytb'
alias -g J='| jq'
alias -g CC='| xclip -selection clipboard'
alias -g C='| wc -l'
alias -g SS='| sort'
alias -g Su='| sort -u'
alias -g Sn='| sort -n'
alias -g Snr='| sort -nr'

# Get public IP address
alias pubip='curl ipinfo.io'

# List apps with network connections
alias netCons='lsof -i'

# List ports
alias tulp='ss -tulp'

# List open ports
alias openPorts='sudo lsof -i | grep LISTEN'

# Ping google.com
alias pong='ping -c 3 www.google.com'

# List sockets in use
alias lsock='sudo lsof -i -P'

# List UDP sockets in use
alias lsockU='sudo lsof -nP | grep UDP'

# List TCP sockets in use
alias lsockT='sudo lsof -nP | grep TCP'

# Reboot / Poweroff
alias rbt='sudo systemctl reboot'
alias shut='sudo systemctl poweroff'

# GPG
alias gpgs='gpg --search-keys'
alias gpgl='gpg --list-keys --with-fingerprint'

# firewalld
if test -x "$(command -v firewall-cmd)"; then
    alias fw='sudo firewall-cmd'
    alias fwp='sudo firewall-cmd --permanent'
    alias fwr='sudo firewall-cmd --reload'
    alias fwrp='sudo firewall-cmd --runtime-to-permanent'
fi

# git
alias ga='git add'
alias gcl='git clone'
alias gcmsg='git commit -m'
alias gd='git diff'
alias gl='git pull'
alias gp='git push'
alias gr='git remote'
alias grbi='git rebase -i'
alias grm='git rm'
alias grv='git remote -v'
alias gst='git status'

